.. _component-adaptation:

ComponentAdaptation
====================
.. inheritance-diagram:: gmmvi.optimization.gmmvi_modules.component_adaptation.ComponentAdaptation gmmvi.optimization.gmmvi_modules.component_adaptation.FixedComponentAdaptation gmmvi.optimization.gmmvi_modules.component_adaptation.VipsComponentAdaptation
    :parts: -4

.. autoclass:: gmmvi.optimization.gmmvi_modules.component_adaptation.ComponentAdaptation
   :members:

.. _fixed-adaptation:

FixedComponentAdaptation
~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.component_adaptation.FixedComponentAdaptation
   :members:

.. _vips-adaptation:

VipsComponentAdaptation
~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.component_adaptation.VipsComponentAdaptation
   :members:

.. toctree::
   :maxdepth: 2
   :glob: